@@ -1,4 +1,4 @@
-# -*- Mode:Python; indent-tabs-mode:nil; tab-width:4; encoding:utf8 -*-
+# -*- Mode:Python; indent-tabs-mode:nil; tab-width:4; encoding:utf-8 -*-
 #
 # Copyright 2002 Ben Escoto <ben@emerose.org>
 # Copyright 2007 Kenneth Loafman <kenneth@loafman.com>
@@ -28,6 +28,7 @@ import os
 import platform
 import subprocess
 import sys
+import pytest
 import unittest
 
 from testing import _runtest_dir
@@ -48,6 +49,7 @@ class RestartTest(FunctionalTestCase):
         self.backup(u"full", u"{0}/testfiles/largefiles".format(_runtest_dir))
         self.verify(u"{0}/testfiles/largefiles".format(_runtest_dir))
 
+    @pytest.mark.slow
     @unittest.skipIf(sys.version_info.major == 2, u"Skip on possible timing error")
     def test_multiple_checkpoint_restart(self):
         u"""
@@ -151,6 +153,7 @@ class RestartTest(FunctionalTestCase):
         self.backup(u"full", u"{0}/testfiles/largefiles".format(_runtest_dir))
         self.verify(u"{0}/testfiles/largefiles".format(_runtest_dir))
 
+    @pytest.mark.slow
     def test_restart_incremental(self):
         u"""
         Test restarting an incremental backup
@@ -370,9 +373,11 @@ class RestartTestWithoutEncryption(RestartTest):
         sigtars = glob.glob(u"{0}/testfiles/output/duplicity-full*.sigtar.gz".format(_runtest_dir))
         self.assertEqual(1, len(sigtars))
         sigtar = sigtars[0]
-        self.assertEqual(0, os.system(u"{0} c --file={1}/testfiles/snapshot.sigtar -C {1}/testfiles snapshot".format(tarcmd, _runtest_dir)))
+        self.assertEqual(0, os.system(u"{0} c --file={1}/testfiles/snapshot.sigtar -C {1}/testfiles snapshot".format(
+            tarcmd, _runtest_dir)))
         self.assertEqual(0, os.system(u"gunzip -c {1} > {0}/testfiles/full.sigtar".format(_runtest_dir, sigtar)))
-        self.assertEqual(0, os.system(u"{0} A --file={1}/testfiles/snapshot.sigtar {1}/testfiles/full.sigtar".format(tarcmd, _runtest_dir)))
+        self.assertEqual(0, os.system(u"{0} A --file={1}/testfiles/snapshot.sigtar {1}/testfiles/full.sigtar".format(
+            tarcmd, _runtest_dir)))
         self.assertEqual(0, os.system(u"gzip {0}/testfiles/snapshot.sigtar".format(_runtest_dir)))
         os.remove(sigtar)
         os.rename(u"{0}/testfiles/snapshot.sigtar.gz".format(_runtest_dir), sigtar)
@@ -385,5 +390,6 @@ class RestartTestWithoutEncryption(RestartTest):
         # Confirm we can restore it (which in buggy versions, would fail)
         self.restore()
 
+
 if __name__ == u"__main__":
     unittest.main()
